API Reference
=============
.. toctree::
    :maxdepth: 4

    consolemenu/ConsoleMenu
    consolemenu/SelectionMenu
    consolemenu/MultiSelectMenu
    items
    consolemenu/functions
    consolemenu/Screen
    consolemenu/components
    consolemenu/format
    consolemenu/prompts

